@@ -147,8 +147,13 @@ ggCatepillar=function(data,mapping,errorbar="se",interactive=FALSE,digits=1,flip
                 #hover_css="fill-opacity=.3;cursor:pointer;stroke:gold;"
                 hover_css="r:4px;cursor:pointer;stroke-width:6px;"
                 selected_css = "fill:#FF3333;stroke:black;"
-                p<-ggiraph(code=print(p),tooltip_extra_css=tooltip_css,tooltip_opacity=.75,
-                           zoom_max=10,hover_css=hover_css,selected_css=selected_css)
+
+                p<-girafe(ggobj=p)
+                p<-girafe_options(p,
+                                  opts_hover(css=hover_css),
+                                  opts_tooltip(css=tooltip_css,opacity=.75),
+                                  opts_selection(css=selected_css),
+                                  opts_zoom(min=1,max=10))
         }
         p
 }
