@@ -98,8 +98,12 @@ ggErrorBar=function(data,mapping,interactive=FALSE,digits=1,mode=2,errorbar="se"
     if(interactive){
             tooltip_css <- "background-color:white;font-style:italic;padding:10px;border-radius:10px 20px 10px 20px;"
             hover_css="r:4px;cursor:pointer;stroke-width:6px;"
-            p<-ggiraph(code=print(p),tooltip_extra_css=tooltip_css,tooltip_opacity=.75,
-                       zoom_max=10,hover_css=hover_css)
+
+            p<-girafe(ggobj=p)
+            p<-girafe_options(p,
+                              opts_hover(css=hover_css),
+                              opts_tooltip(css=tooltip_css,opacity=.75),
+                              opts_zoom(min=1,max=10))
     }
     p
 }
