@@ -193,7 +193,14 @@ ggPieDonut=function(data,mapping,
 
                 }
 
-                if(interactive) p<-ggiraph(code=print(p),zoom_max=10)
+                if(interactive) {
+                        tooltip_css <- "background-color:white;font-style:italic;padding:10px;border-radius:10px 20px 10px 20px;"
+                        p<-girafe(ggobj=p)
+                        p<-girafe_options(p,
+                                          opts_tooltip(css=tooltip_css,opacity=.75),
+                                          opts_zoom(min=1,max=10))
+
+                }
                 p
 
         }
@@ -343,7 +350,13 @@ ggDonut=function(data,mapping,
         #
         # }
 
-        if(interactive) p<-ggiraph(code=print(p),zoom_max = 10)
+        if(interactive) {
+                tooltip_css <- "background-color:white;font-style:italic;padding:10px;border-radius:10px 20px 10px 20px;"
+                p<-girafe(ggobj=p)
+                p<-girafe_options(p,
+                                  opts_tooltip(css=tooltip_css,opacity=.75),
+                                  opts_zoom(min=1,max=10))
+        }
         p
 
 }
@@ -499,7 +512,15 @@ ggPie=function(data,mapping,
 
         }
 
-        if(interactive) p<-ggiraph(code=print(p),zoom_max=10)
+        if(interactive) {
+                tooltip_css <- "background-color:white;font-style:italic;padding:10px;border-radius:10px 20px 10px 20px;"
+                p<-girafe(ggobj=p)
+                p<-girafe_options(p,
+                                  opts_tooltip(css=tooltip_css,opacity=.75),
+                                  opts_zoom(min=1,max=10))
+
+
+        }
         p
 
 }
